vmd — Remote Tcl commands in VMD — GromacsWrapper 0.4.0-dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- GromacsWrapper 0.4.0-dev documentation »
- Auxiliary modules »

# `vmd` — Remote Tcl commands in VMD

The `vmd` module contains a very simple client that can connect to a locally running server process in VMD. This allows running VMD Tcl commands remotely. See VMD Tcl Text Commands for all available commands.

The `vmd` module is independent from `gromacs` and distribute for convenience. It can be used to implement additional visualization and analysis tasks.

### Navigation

- index
- modules |
- next |
- previous |
- GromacsWrapper 0.4.0-dev documentation »
- Auxiliary modules »